====================================
``psyclone.tests.kernel_tools_test``
====================================

.. automodule:: psyclone.tests.kernel_tools_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.kernel_tools_test
